Type
  {$ ::ctrl.healthmonitor.type $}
Delay
  {$ ::ctrl.healthmonitor.delay $}
Max Retries
  {$ ::ctrl.healthmonitor.max_retries $}
Timeout
  {$ ::ctrl.healthmonitor.timeout $}
HTTP Method
  {$ ::ctrl.healthmonitor.http_method $}
Expected Codes
  {$ ::ctrl.healthmonitor.expected_codes $}
URL Path
  {$ ::ctrl.healthmonitor.url_path $}
Admin State Up
  {$ ctrl.healthmonitor.admin_state_up | yesno $}
Monitor ID
  {$ ::ctrl.healthmonitor.id $}
Tenant ID
  {$ ::ctrl.healthmonitor.tenant_id $}